@@ -17,11 +17,14 @@ use crate::messaging::data::{CmdError, DataQuery, ServiceMsg};
 use crate::types::{ChunkAddress, Keypair, PublicKey};
 
 use crate::messaging::{ServiceAuth, WireMsg};
+use crate::prefix_map::NetworkPrefixMap;
 use itertools::Itertools;
 use rand::rngs::OsRng;
 use std::collections::BTreeSet;
 use std::net::SocketAddr;
 use std::sync::Arc;
+use tokio::fs::File;
+use tokio::io::AsyncReadExt;
 use tokio::{
     sync::{mpsc::Receiver, RwLock},
     time::Duration,
@@ -52,11 +55,21 @@ impl Client {
     ///
     /// TODO: update once data types are crdt compliant
     ///
+    ///
     #[instrument(skip_all, level = "debug", name = "New client")]
     pub async fn new(
         config: Config,
         bootstrap_nodes: BTreeSet<SocketAddr>,
         optional_keypair: Option<Keypair>,
+    ) -> Result<Self, Error> {
+        Client::create_with(config, bootstrap_nodes, optional_keypair, true).await
+    }
+
+    pub(crate) async fn create_with(
+        config: Config,
+        bootstrap_nodes: BTreeSet<SocketAddr>,
+        optional_keypair: Option<Keypair>,
+        read_prefixmap: bool,
     ) -> Result<Self, Error> {
         let mut rng = OsRng;
 
@@ -75,6 +88,38 @@ impl Client {
             }
         };
 
+        let mut prefix_map_dir = dirs_next::home_dir()
+            .ok_or_else(|| Error::Generic("Error opening home dir".to_string()))?;
+        prefix_map_dir.push(".safe");
+        prefix_map_dir.push("prefix_map");
+
+        // Read NetworkPrefixMap from disk if present else create a new one
+        let prefix_map = if let (Ok(mut prefix_map_file), true) =
+            (File::open(prefix_map_dir).await, read_prefixmap)
+        {
+            let mut prefix_map_contents = vec![];
+            let _ = prefix_map_file
+                .read_to_end(&mut prefix_map_contents)
+                .await?;
+
+            let prefix_map: NetworkPrefixMap = rmp_serde::from_slice(&prefix_map_contents)
+                .map_err(|err| {
+                    Error::Generic(format!(
+                        "Error deserializing PrefixMap from disk: {:?}",
+                        err
+                    ))
+                })?;
+            prefix_map
+        } else {
+            NetworkPrefixMap::new(config.genesis_key)
+        };
+
+        if config.genesis_key != prefix_map.genesis_key() {
+            return Err(Error::Generic(
+                "Genesis Key from the config and the PrefixMap mismatch".to_string(),
+            ));
+        }
+
         // Incoming error notifiers
         let (err_sender, err_receiver) = tokio::sync::mpsc::channel::<CmdError>(10);
 
@@ -87,9 +132,6 @@ impl Client {
             hex::encode(config.genesis_key.to_bytes())
         );
 
-        // Session wait time. We want this relative to query timeout for now. Which defaults to 90s
-        let standard_wait = config.query_timeout / 10;
-
         // Create a session with the network
         let session = Session::new(
             client_pk,
@@ -97,7 +139,8 @@ impl Client {
             config.qp2p,
             err_sender,
             config.local_addr,
-            standard_wait,
+            config.standard_wait,
+            prefix_map,
         )
         .await?;
 
@@ -126,7 +169,7 @@ impl Client {
 
         let bootstrap_nodes = bootstrap_nodes.iter().copied().collect_vec();
 
-        // TODO: check for the intiial msg id and DO NOT RESEND in ae retry.
+        // TODO: check for the initial msg id and DO NOT RESEND in ae retry.
         // Send the dummy message to probe the network for it's infrastructure details.
         client
             .session
@@ -209,7 +252,7 @@ mod tests {
         let full_id = Keypair::new_ed25519(&mut rng);
         let pk = full_id.public_key();
 
-        let client = create_test_client_with(Some(full_id), None).await?;
+        let client = create_test_client_with(Some(full_id), None, true).await?;
         assert_eq!(pk, client.public_key());
 
         Ok(())
