@@ -51,6 +51,7 @@ impl Core {
             event_tx,
             used_space,
             root_storage_dir,
+            true,
         )
         .await
     }
@@ -81,6 +82,7 @@ impl Core {
             relocate_state: None,
             event_tx: self.event_tx.clone(),
             joins_allowed: Arc::new(RwLock::new(true)),
+            is_genesis_node: false,
             resource_proof: ResourceProof::new(RESOURCE_PROOF_DATA_SIZE, RESOURCE_PROOF_DIFFICULTY),
             register_storage: self.register_storage.clone(),
             root_storage_dir: self.root_storage_dir.clone(),
